import { DebugConnection, DebuggeeEvent } from './connection.js';
import { ContextEvent, QuickJSDebugSession, StoppedEvent } from './session.js';
export interface ProtocolInfo {
    version: number;
    targetModuleUuid?: string;
}
export declare enum LogLevel {
    Verbose = 0,
    Info = 1,
    Warn = 2,
    Error = 3,
    Fatal = 4
}
export interface LogEvent extends DebuggeeEvent {
    type: 'PrintEvent';
    message: string;
    logLevel: LogLevel;
}
export interface ProtocolEvent extends DebuggeeEvent {
    type: 'ProtocolEvent';
    version: number;
}
export interface StatDataV1 {
    id: string;
    parent_id?: string;
    type?: string;
    label?: string;
    value?: string | number;
}
export interface StatDataModel {
    name: string;
    children?: StatDataModel[];
    values?: number[];
}
export interface StatMessageV1Event extends DebuggeeEvent {
    type: 'StatEvent';
    stats: StatDataV1[];
}
export interface StatMessageV2Event extends DebuggeeEvent {
    type: 'StatEvent2';
    tick: number;
    stats: StatDataModel[];
}
export interface StatTreeNode {
    name: string;
    label?: string;
    type?: string;
    updateTick?: number;
    values?: (string | number)[];
    children?: StatTree;
}
export type StatTree = Record<string, StatTreeNode | undefined>;
export interface StatEvent {
    stat: StatTree;
    tick: number;
}
export declare class MinecraftDebugSession extends QuickJSDebugSession {
    protocolInfo?: ProtocolInfo;
    currentStat: StatTree | null;
    currentTick: number;
    constructor(connection: DebugConnection);
    setProtocolInfo(protocolInfo: ProtocolInfo): void;
}
export interface MinecraftDebugSessionEventMap {
    log: (event: LogEvent) => void;
    protocol: (event: ProtocolEvent) => void;
    stat: (event: StatMessageV2Event) => void;
}
export interface MinecraftDebugSession {
    on(eventName: 'stopped', listener: (event: StoppedEvent) => void): this;
    on(eventName: 'context', listener: (event: ContextEvent) => void): this;
    on(eventName: 'end', listener: () => void): this;
    on(eventName: 'log', listener: (event: LogEvent) => void): this;
    on(eventName: 'protocol', listener: (event: ProtocolEvent) => void): this;
    on(eventName: 'stat', listener: (event: StatEvent) => void): this;
    once(eventName: 'stopped', listener: (event: StoppedEvent) => void): this;
    once(eventName: 'context', listener: (event: ContextEvent) => void): this;
    once(eventName: 'end', listener: () => void): this;
    once(eventName: 'log', listener: (event: LogEvent) => void): this;
    once(eventName: 'protocol', listener: (event: ProtocolEvent) => void): this;
    once(eventName: 'stat', listener: (event: StatEvent) => void): this;
    off(eventName: 'stopped', listener: (event: StoppedEvent) => void): this;
    off(eventName: 'context', listener: (event: ContextEvent) => void): this;
    off(eventName: 'end', listener: () => void): this;
    off(eventName: 'log', listener: (event: LogEvent) => void): this;
    off(eventName: 'protocol', listener: (event: ProtocolEvent) => void): this;
    off(eventName: 'stat', listener: (event: StatEvent) => void): this;
    addListener(eventName: 'stopped', listener: (event: StoppedEvent) => void): this;
    addListener(eventName: 'context', listener: (event: ContextEvent) => void): this;
    addListener(eventName: 'end', listener: () => void): this;
    addListener(eventName: 'log', listener: (event: LogEvent) => void): this;
    addListener(eventName: 'protocol', listener: (event: ProtocolEvent) => void): this;
    addListener(eventName: 'stat', listener: (event: StatEvent) => void): this;
    removeListener(eventName: 'stopped', listener: (event: StoppedEvent) => void): this;
    removeListener(eventName: 'context', listener: (event: ContextEvent) => void): this;
    removeListener(eventName: 'end', listener: () => void): this;
    removeListener(eventName: 'log', listener: (event: LogEvent) => void): this;
    removeListener(eventName: 'protocol', listener: (event: ProtocolEvent) => void): this;
    removeListener(eventName: 'stat', listener: (event: StatEvent) => void): this;
    emit(eventName: 'stopped', event: StoppedEvent): boolean;
    emit(eventName: 'context', event: ContextEvent): boolean;
    emit(eventName: 'end'): boolean;
    emit(eventName: 'log', event: LogEvent): boolean;
    emit(eventName: 'protocol', event: ProtocolEvent): boolean;
    emit(eventName: 'stat', event: StatEvent): boolean;
}
