import { QuickJSDebugSession } from './session.js';
export var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["Verbose"] = 0] = "Verbose";
    LogLevel[LogLevel["Info"] = 1] = "Info";
    LogLevel[LogLevel["Warn"] = 2] = "Warn";
    LogLevel[LogLevel["Error"] = 3] = "Error";
    LogLevel[LogLevel["Fatal"] = 4] = "Fatal";
})(LogLevel || (LogLevel = {}));
function mergeStatTreeNodeV1(target, updated, pathCache) {
    for (const statData of updated) {
        const path = [];
        if (statData.parent_id) {
            const cachedPath = pathCache.get(statData.parent_id);
            if (cachedPath) {
                path.push(...cachedPath);
            }
            else {
                continue;
            }
        }
        let currentTarget = target;
        for (const part of path) {
            const newTargetOwner = currentTarget[part];
            if (!newTargetOwner) {
                throw new Error(`Cannot find node in stat tree: ${path.join('->')}`);
            }
            currentTarget = newTargetOwner.children ?? (newTargetOwner.children = {});
        }
        if (!pathCache.has(statData.id)) {
            pathCache.set(statData.id, [...path, statData.id]);
        }
        let existed = currentTarget[statData.id];
        if (!existed) {
            existed = currentTarget[statData.id] = { name: statData.id };
        }
        existed.label = statData.label;
        existed.type = statData.type;
        if (statData.value !== undefined) {
            existed.values = [statData.value];
        }
    }
}
function mergeStatTreeNodeV2(target, updated, tick) {
    for (const statData of updated) {
        let existed = target[statData.name];
        if (!existed) {
            existed = target[statData.name] = { name: statData.name };
        }
        existed.updateTick = tick;
        if (statData.values !== undefined) {
            existed.values = statData.values;
        }
        if (statData.children) {
            const children = existed.children ?? (existed.children = {});
            mergeStatTreeNodeV2(children, statData.children, tick);
        }
    }
}
export class MinecraftDebugSession extends QuickJSDebugSession {
    constructor(connection) {
        super(connection);
        this.currentStat = null;
        this.currentTick = 0;
        connection.on('PrintEvent', (ev) => {
            this.emit('log', ev);
        });
        connection.on('ProtocolEvent', (ev) => {
            this.emit('protocol', ev);
            if (this.protocolInfo) {
                const protocolInfo = this.protocolInfo;
                this.connection.sendMessage({
                    type: 'protocol',
                    version: protocolInfo.version,
                    target_module_uuid: protocolInfo.targetModuleUuid
                });
            }
        });
        const v1PathCache = new Map();
        connection.on('StatEvent', (ev) => {
            const stat = this.currentStat ?? (this.currentStat = {});
            mergeStatTreeNodeV1(stat, ev.stats, v1PathCache);
            this.emit('stat', { stat, tick: this.currentTick });
        });
        connection.on('StatEvent2', (ev) => {
            const stat = this.currentStat ?? (this.currentStat = {});
            this.currentTick = ev.tick;
            mergeStatTreeNodeV2(stat, ev.stats, ev.tick);
            this.emit('stat', { stat, tick: ev.tick });
        });
    }
    setProtocolInfo(protocolInfo) {
        this.protocolInfo = protocolInfo;
    }
}
//# sourceMappingURL=minecraft.js.map